aboutsummaryrefslogtreecommitdiffstats
path: root/scd/app-help.c
diff options
context:
space:
mode:
authorWerner Koch <[email protected]>2020-05-05 06:07:11 +0000
committerWerner Koch <[email protected]>2020-05-05 06:07:11 +0000
commit314859d7e7de5010ca1e9d90b83acf3bc8493631 (patch)
tree7fb017efa8cac15991ce5fc0c8839d7db2c2c8c6 /scd/app-help.c
parentscd:nks: Add do_with_keygrip and implement a cache. (diff)
downloadgnupg-314859d7e7de5010ca1e9d90b83acf3bc8493631.tar.gz
gnupg-314859d7e7de5010ca1e9d90b83acf3bc8493631.zip
scd: Extend an internal function to also return the algo.
* scd/app-help.c (app_help_get_keygrip_string_pk): Add optional arg r_algo. Change all callers. (app_help_get_keygrip_string): Ditto. Signed-off-by: Werner Koch <[email protected]>
Diffstat (limited to 'scd/app-help.c')
-rw-r--r--scd/app-help.c20
1 files changed, 13 insertions, 7 deletions
diff --git a/scd/app-help.c b/scd/app-help.c
index 4be9b8776..f2b592399 100644
--- a/scd/app-help.c
+++ b/scd/app-help.c
@@ -54,12 +54,13 @@ app_help_count_bits (const unsigned char *a, size_t len)
/* Return the KEYGRIP for the canonical encoded public key (PK,PKLEN)
* as an hex encoded string in the user provided buffer HEXKEYGRIP
* which must be of at least 41 bytes. If R_PKEY is not NULL and the
* function succeeded, the S-expression representing the key is
* stored there. The caller needs to call gcry_sexp_release on
* that. */
gpg_error_t
app_help_get_keygrip_string_pk (const void *pk, size_t pklen, char *hexkeygrip,
- gcry_sexp_t *r_pkey)
+ gcry_sexp_t *r_pkey, int *r_algo)
{
gpg_error_t err;
gcry_sexp_t s_pkey;
@@ -77,6 +78,9 @@ app_help_get_keygrip_string_pk (const void *pk, size_t pklen, char *hexkeygrip,
return gpg_error (GPG_ERR_GENERAL); /* Failed to calculate the keygrip.*/
}
+ if (r_algo)
+ *r_algo = get_pk_algo_from_key (s_pkey);
+
if (r_pkey)
*r_pkey = s_pkey;
else
@@ -92,10 +96,11 @@ app_help_get_keygrip_string_pk (const void *pk, size_t pklen, char *hexkeygrip,
* string in the user provided buffer HEXKEYGRIP which must be of at
* least 41 bytes. If R_PKEY is not NULL and the function succeeded,
* the S-expression representing the key is stored there. The caller
- * needs to call gcry_sexp_release on that. */
+ * needs to call gcry_sexp_release on that. If R_ALGO is not NULL the
+ * public key algorithm id of Libgcrypt is stored there. */
gpg_error_t
app_help_get_keygrip_string (ksba_cert_t cert, char *hexkeygrip,
- gcry_sexp_t *r_pkey)
+ gcry_sexp_t *r_pkey, int *r_algo)
{
gpg_error_t err;
ksba_sexp_t p;
@@ -110,7 +115,8 @@ app_help_get_keygrip_string (ksba_cert_t cert, char *hexkeygrip,
n = gcry_sexp_canon_len (p, 0, NULL, NULL);
if (!n)
return gpg_error (GPG_ERR_INV_SEXP);
- err = app_help_get_keygrip_string_pk ((void*)p, n, hexkeygrip, r_pkey);
+ err = app_help_get_keygrip_string_pk ((void*)p, n, hexkeygrip,
+ r_pkey, r_algo);
ksba_free (p);
return err;
}
@@ -54,12 +54,13 @@ app_help_count_bits (const unsigned char *a, size_t len)
* as an hex encoded string in the user provided buffer HEXKEYGRIP
* which must be of at least 41 bytes. If R_PKEY is not NULL and the
- * function succeeded, the S-expression representing the key is
- * stored there. The caller needs to call gcry_sexp_release on
- * that. */
+ * function succeeded, the S-expression representing the key is stored
+ * there. The caller needs to call gcry_sexp_release on that. If
+ * R_ALGO is not NULL the public key algorithm id of Libgcrypt is
+ * stored there. */
gpg_error_t
app_help_get_keygrip_string_pk (const void *pk, size_t pklen, char *hexkeygrip,